"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("fs");
const core_1 = require("@checkup/core");
const sloc = require('sloc');
/*
 * note: these extensions must be supported here https://github.com/flosse/sloc/blob/731fbea00799a45a6068c4aaa1d6b7f67500615e/src/sloc.coffee#L264
 * for the analysis on comments/empty lines/etc to be correct
 */
const FILE_EXTENSIONS_SUPPORTED = new Set(sloc.extensions);
class LinesOfCodeTask extends core_1.BaseTask {
    constructor() {
        super(...arguments);
        this.taskName = 'lines-of-code';
        this.taskDisplayName = 'Lines Of Code';
        this.description = 'Counts lines of code within a project';
        this.category = 'info';
    }
    async run() {
        let fileInfos = await this.getLinesOfCode();
        fileInfos.forEach((fileInfo) => {
            this.addResult(`Lines of code count for ${fileInfo.filePath} - total lines: ${fileInfo.lines}`, 'informational', 'note', {
                location: {
                    uri: fileInfo.filePath,
                },
                properties: Object.assign({}, fileInfo),
                rule: {
                    properties: {
                        component: {
                            name: 'table',
                            options: {
                                sumBy: {
                                    findGroupBy: 'Language',
                                    sumValueBy: 'Total Lines',
                                },
                                rows: {
                                    Language: 'properties.extension',
                                    'Total Lines': 'properties.lines',
                                },
                            },
                        },
                    },
                },
            });
        });
        return this.results;
    }
    async getLinesOfCode() {
        let fileInfos = [];
        await Promise.all(this.context.paths
            .filter((filePath) => {
            let extension = getExtension(filePath);
            return FILE_EXTENSIONS_SUPPORTED.has(extension);
        })
            .map(async (filePath) => {
            const contents = await fs_1.promises.readFile(filePath, 'utf8');
            let extension = getExtension(filePath);
            let { total } = sloc(contents, extension);
            fileInfos.push({
                filePath: filePath.replace(this.context.options.cwd, ''),
                extension,
                lines: total,
            });
        }));
        return fileInfos;
    }
}
exports.default = LinesOfCodeTask;
function getExtension(filePath) {
    return path_1.extname(filePath).replace('.', '');
}
//# sourceMappingURL=lines-of-code-task.js.map