"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const core_1 = require("@checkup/core");
class OutdatedDependenciesTask extends core_1.BaseTask {
    constructor() {
        super(...arguments);
        this.taskName = 'outdated-dependencies';
        this.taskDisplayName = 'Outdated Dependencies';
        this.description = 'Gets a summary of all outdated dependencies in a project';
        this.category = 'dependencies';
    }
    async run() {
        let analyzer = new core_1.DependencyAnalyzer(this.context.options.cwd);
        let dependencies = await analyzer.analyze();
        dependencies
            .filter((dependency) => {
            return ['major', 'minor', 'patch'].includes(dependency.semverBump);
        })
            .forEach((dependency) => {
            this.addResult(`Outdated ${dependency.semverBump} version of ${dependency.packageName}. Installed: ${dependency.installedVersion}. Latest: ${dependency.latestVersion}.`, 'review', getLevel(dependency.semverBump), {
                location: {
                    uri: path_1.join(this.context.options.cwd, 'package.json'),
                    startColumn: dependency.startColumn,
                    startLine: dependency.startLine,
                    endColumn: dependency.endColumn,
                    endLine: dependency.endLine,
                },
                properties: {
                    packageName: dependency.packageName,
                    packageVersion: dependency.packageVersion,
                    latestVersion: dependency.latestVersion,
                    type: dependency.type,
                },
                rule: {
                    properties: {
                        component: {
                            name: 'table',
                            options: {
                                rows: {
                                    Dependency: 'properties.packageName',
                                    Installed: 'properties.packageVersion',
                                    Latest: 'properties.latestVersion',
                                },
                            },
                        },
                    },
                },
            });
        });
        return this.results;
    }
}
exports.default = OutdatedDependenciesTask;
function getLevel(semverBump) {
    switch (semverBump) {
        case 'major': {
            return 'error';
        }
        case 'minor': {
            return 'warning';
        }
        case 'patch': {
            return 'note';
        }
        default: {
            return 'none';
        }
    }
}
//# sourceMappingURL=outdated-dependencies-task.js.map